from distutils.core import setup
setup(
    name = "talepy",
    packages = ["talepy"],
    version = "0.1.0",
    description = "Distributed Transactions Helper",
    author = "Steve Brazier",
    author_email = "meadsteve@gmail.com",
    url = "https://github.com/meadsteve/talepy",
    keywords = ["saga", "distributed transaction"],
    classifiers = [
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
        ],
    long_description = """\
Tale Distributed Transactions
-------------------------------------

"""
)